@@ -11,7 +11,6 @@ from openpyxl import Workbook, load_workbook
 from openpyxl.styles import PatternFill
 from plotly.colors import hex_to_rgb, n_colors
 from plotly.graph_objects import Figure, Sunburst
-
 from plotly.offline import plot as plotly_plot
 from plotly.subplots import make_subplots
 
@@ -31,7 +30,7 @@ def rgb_to_hex(rgb: tuple = None) -> str:
     # necessary due to weird behaviour introduced by plotly
     # test = plotly.colors.ncolors(lowcolor=(64, 60, 83), highcolor=(255, 0, 255), n_colors=11001)
     # print(test[-1])
-    if any([False if 0 <= _ < 256 else True for _ in rgb]):
+    if any(False if 0 <= _ < 256 else True for _ in rgb):
         for idx, color in enumerate(rgb):
             if color < 0:
                 tmp = list(rgb)
@@ -41,7 +40,7 @@ def rgb_to_hex(rgb: tuple = None) -> str:
     return f"#{int(rgb[0]):02X}{int(rgb[1]):02X}{int(rgb[2]):02X}"
 
 
-def generate_color_range(start_color: str = None, stop_color: str = None, values: int = None) -> list[str]:
+def generate_color_range(start_color: str = None, stop_color: str = None, values: int = None) -> list:
     """Calculate color range based on start and stop color and number of values
 
     :param start_color: start color as RGB hex
@@ -124,8 +123,8 @@ class SunburstBase:
                         elif len(columns) == 7:
                             file_type = "mesh_tsv"
                         else:
-                            raise ValueError(f"TSV verification failed. "
-                                             f"Expected 6 columns for ATC-tree, 7 columns for MeSH tree")
+                            raise ValueError("TSV verification failed. Expected 6 columns for ATC-tree, "
+                                             "7 columns for MeSH tree")
                         print(f"TSV verified as '{file_type}': {fn}")
                         return file_type
 
@@ -182,9 +181,9 @@ class SunburstBase:
             # resolve booleans
             if k in ["show_border", "export_plot", "mesh_drop_empty_last_child",
                      "atc_propagate_enable", "mesh_propagate_enable"]:
-                if v == "True" or v == "TRUE" or v == "1" or v == 1:
+                if v in ["True", "TRUE", "1", 1]:
                     v = True
-                elif v == "False" or v == "FALSE" or v == "0" or v == 0:
+                elif v in ["False", "FALSE", "0", 0]:
                     v = False
                 else:
                     raise ValueError(f"Illegal value for setting '{k}': '{v}' - boolean required")
@@ -329,7 +328,7 @@ class SunburstBase:
         return self.get_entity_id(drug_name, "drug")
 
     def calculate_color_scale_for_node(self, sub_tree: dict = None, max_val: int = None, max_level: [str, int] = None,
-                                       count_key: str = "counts") -> tuple[int, list[str]]:
+                                       count_key: str = "counts") -> tuple:
         """Get color scale based on max value of counts of children in a subtree
 
         :param sub_tree: MeSH/ATC subtree dictionary (e.g. mesh_tree['C01']) (e.g. atc_tree['L'])
@@ -401,9 +400,7 @@ class SunburstBase:
         elif isinstance(self, PhenotypeSunburst):
             return sum([int(vv[count_key]) for k, v in self.mesh_tree.items() for kk, vv in v.items()])
 
-    # def get_header_from_row(self, row:):
-
-    def export_settings(self, fn: [str, None] = None, wb: Workbook = None, settings: list[tuple] = None) -> str:
+    def export_settings(self, fn: [str, None] = None, wb: Workbook = None, settings: list = None) -> str:
         """Subroutine to write settings to workbook
 
         :param fn: target filename
@@ -448,8 +445,8 @@ class SunburstBase:
         print(f"\tExported to: {os.path.abspath(fn)}")
         return os.path.abspath(fn)
 
-    def export_tree_to_excel(self, fn: str = None, header: list[str] = None, rows: list[tuple] = None,
-                             settings: list[tuple] = None, color_col: int = None) -> str:
+    def export_tree_to_excel(self, fn: str = None, header: list = None, rows: list = None,
+                             settings: list = None, color_col: int = None) -> str:
         """Export Tree to Excel
 
         :param fn: target filename
@@ -470,11 +467,12 @@ class SunburstBase:
         column_widths = [len(_) for _ in header]
         for idx, (width, col_letter) in enumerate(zip(column_widths, ascii_uppercase[:len(column_widths)])):
             max_row_width = len(str(max(rows, key=lambda x: len(str(x[idx])))[idx]))
+            current_col_width = int(width)
             if width <= max_row_width <= 100:
-                width = max_row_width
+                current_col_width = max_row_width
             elif max_row_width > 100:
-                width = 100
-            ws.column_dimensions[col_letter].width = width + 2
+                current_col_width = 100
+            ws.column_dimensions[col_letter].width = current_col_width + 2
 
         # write rows to worksheet, apply color to cells
         for r in rows:
@@ -487,7 +485,7 @@ class SunburstBase:
         return self.export_settings(fn=fn, wb=wb, settings=settings)
 
     @staticmethod
-    def export_tree_to_tsv(fn: str = None, header: list[str] = None, rows: list[tuple] = None) -> str:
+    def export_tree_to_tsv(fn: str = None, header: list = None, rows: list = None) -> str:
         """Export Tree to TSV
 
         :param fn: target filename
@@ -501,7 +499,7 @@ class SunburstBase:
         try:
             file = open(fn, mode="w", encoding="utf-8")
         except PermissionError:
-            print(f"\tFile already exists - appending timestamp ..")
+            print("\tFile already exists - appending timestamp ..")
             fn = os.path.splitext(fn)[0] + f"_{datetime.now().strftime('%Y-%m-%d_%H-%M-%S')}.tsv"
             file = open(fn, mode="w", encoding="utf-8")
         finally:
@@ -589,7 +587,7 @@ class SunburstBase:
                         else:
                             plot_tree[k][kk]["color"] = self.s["default_color"]
 
-    def generate_plot_supplements(self, plot_tree: dict = None) -> (list[list[str]], list[list[tuple[int, str]]], str):
+    def generate_plot_supplements(self, plot_tree: dict = None) -> tuple:
         """Generates nested lists for subtrees containing label, percentage, custom data etc. used for sunburst traces
 
         :param plot_tree: dictionary containing trees and nodes
@@ -639,27 +637,24 @@ class SunburstBase:
             for kk, vv in v.items():
 
                 # wedge labels
-                match label_mode:
-                    case "all":
-                        wedge_labels.append(vv["label"])
-                    case "propagation":
-                        wedge_labels.append(vv["label"] if vv["level"] >= propagate_lvl else "")
-                    case "drugs":
-                        wedge_labels.append(vv["label"] if vv["level"] == 5 else "")
-                    case "none":
-                        wedge_labels.append("")
+                if label_mode == "all":
+                    wedge_labels.append(vv["label"])
+                elif label_mode == "propagation":
+                    wedge_labels.append(vv["label"] if vv["level"] >= propagate_lvl else "")
+                elif label_mode == "drugs":
+                    wedge_labels.append(vv["label"] if vv["level"] == 5 else "")
+                elif label_mode == "none":
+                    wedge_labels.append("")
 
                 # percentages
-                match propagate_count_mode:
-                    case "off" | "all":
+                if propagate_count_mode in ["off", "all"]:
+                    node_percentage = round(vv["imported_counts"] / sub_tree_sum * 100, 1)
+                elif propagate_count_mode == "level":
+                    if vv["level"] >= propagate_lvl:
+                        node_percentage = round(vv["imported_counts"] / propagate_threshold_sum * 100)
+                    else:
                         node_percentage = round(vv["imported_counts"] / sub_tree_sum * 100, 1)
 
-                    case "level":
-                        if vv["level"] >= propagate_lvl:
-                            node_percentage = round(vv["imported_counts"] / propagate_threshold_sum * 100)
-                        else:
-                            node_percentage = round(vv["imported_counts"] / sub_tree_sum * 100, 1)
-
                 # custom data
                 hover_label = vv["label"] if vv["label"] != "" else "Undefined"
                 count = int(vv["imported_counts"])
@@ -767,12 +762,12 @@ class SunburstBase:
             self.set_thread_status(f"Exported plot to: {abs_path}")
             self.thread_return = abs_path
         else:
-            self.set_thread_status(f"Sunburst created")
+            self.set_thread_status("Sunburst created")
             fig.show(config=config)
 
     @staticmethod
-    def generate_subplot_figure(cols: int = None, traces: list[Sunburst] = None,
-                                headers: list[str] = None, title: str = None) -> Figure:
+    def generate_subplot_figure(cols: int = None, traces: list = None,
+                                headers: list = None, title: str = None) -> Figure:
         """Generates a subplot figure based on list of Sunburst traces and settings
 
         :param cols: Number of columns
@@ -1169,7 +1164,7 @@ class PhenotypeSunburst(SunburstBase):
 
         # propagate counts up
         if self.s["mesh_propagate_enable"]:
-            self.set_thread_status(f"Propagating counts ..")
+            self.set_thread_status("Propagating counts ..")
             for k, v in plot_tree.items():
                 for kk, vv in v.items():
 
@@ -1180,14 +1175,14 @@ class PhenotypeSunburst(SunburstBase):
                         continue
 
                     # apply count propagation
-                    match self.s["mesh_propagate_counts"]:
-                        case "off":
-                            continue
-                        case "level":
-                            if parent["level"] >= self.s["mesh_propagate_lvl"]:
-                                parent["imported_counts"] += vv["imported_counts"]
-                        case "all":
+                    propagate_mode = self.s["mesh_propagate_counts"]
+                    if propagate_mode == "off":
+                        continue
+                    elif propagate_mode == "level":
+                        if parent["level"] >= self.s["mesh_propagate_lvl"]:
                             parent["imported_counts"] += vv["imported_counts"]
+                    elif propagate_mode == "all":
+                        parent["imported_counts"] += vv["imported_counts"]
 
         # when counts are propagated, begin color propagation
         self.tree_color_propagation(plot_tree=plot_tree, count_key="imported_counts")
@@ -1273,8 +1268,8 @@ class DrugSunburst(SunburstBase):
         """
         print("Exporting ATC-tree ..")
         if template:
-            fn_base = f"atc_tree_template"
-            header = ["ATC code", "Level", "Label", "Comment", f"Counts [Template Phenotype]", "Color"]
+            fn_base = "atc_tree_template"
+            header = ["ATC code", "Level", "Label", "Comment", "Counts [Template Phenotype]", "Color"]
         else:
             fn_base = f"atc_tree_{self.phenotype_name.lower()}"
             header = ["ATC code", "Level", "Label", "Comment", f"Counts [{self.phenotype_name}]", "Color"]
@@ -1461,23 +1456,23 @@ class DrugSunburst(SunburstBase):
         :param read_settings: If True, settings from Excel will be loaded and applied
         :param populate: If True, ATC tree is loaded and processed
         """
-        wb = load_workbook(fn, read_only=True)
+        work_book = load_workbook(fn, read_only=True)
         self.rollback_atc_tree()
 
         # read & iterate over excel - load settings
         if read_settings:
-            self.read_atc_settings_from_excel(wb=wb)
+            self.read_atc_settings_from_excel(wb=work_book)
 
         # load tree data
         if populate:
             print(f"Loading ATC-tree from {fn} ..")
             try:
-                ws = wb["Tree"]
+                work_sheet = work_book["Tree"]
             except KeyError:
-                ws = wb.worksheets[0]
-            self.process_atc_row_data(row_data=ws.rows)
+                work_sheet = work_book.worksheets[0]
+            self.process_atc_row_data(row_data=work_sheet.rows)
 
-        wb.close()
+        work_book.close()
 
     def populate_atc_from_data_source(self, phenotype_name: str = None, data_source: str = None):
         """Populates the ATC tree from a data source (database)
@@ -1508,20 +1503,21 @@ class DrugSunburst(SunburstBase):
 
         # add drug counts directly based on chembl_id(s) to level 5
         for node in self.atc_tree.values():
-            for v in node.values():
-                if v["level"] == 5:
-                    for chembl_id in v["chembl_ids"]:
+            for val in node.values():
+                if val["level"] == 5:
+                    for chembl_id in val["chembl_ids"]:
                         if chembl_id in self.drug_counts.keys():
-                            v["counts"] += self.drug_counts[chembl_id]
-                            v["imported_counts"] += self.drug_counts[chembl_id]
+                            val["counts"] += self.drug_counts[chembl_id]
+                            val["imported_counts"] += self.drug_counts[chembl_id]
 
             # calculate color scale, apply to level 5 only
             factor, scale = self.calculate_color_scale_for_node(node)
-            for v in node.values():
-                if v["level"] == 5:
-                    v["color"] = scale[int(v["counts"] / factor)]
+            for val in node.values():
+                if val["level"] == 5:
+                    val["color"] = scale[int(val["counts"] / factor)]
 
-        print(f"\tAdded {self.get_total_counts(count_key='counts')} counts for phenotype '{self.phenotype_name}'")
+        print(f"\tAdded {self.get_total_counts(count_key='counts')} counts "
+              f"for phenotype '{self.phenotype_name}'")
 
     def plot(self):
         """Generate data for drug sunburst plot"""
@@ -1529,37 +1525,35 @@ class DrugSunburst(SunburstBase):
         self.thread_return = None
 
         # create & sort plot tree
-
-        plot_tree = {k: v for k, v in sorted(self.atc_tree.items())}
+        plot_tree = dict(sorted(self.atc_tree.items()))
 
         # setup counts, propagate if enabled
-        for k, v in plot_tree.items():
-            for kk, vv in v.items():
+        for key, val in plot_tree.items():
+            for inner_val in val.values():
 
                 # set all level 5 nodes to at least self.fake_one if loaded from file
-                if vv["level"] == 5:
-                    if vv["imported_counts"] <= 1:
-                        vv["counts"] = self.fake_one
+                if inner_val["level"] == 5:
+                    if inner_val["imported_counts"] <= 1:
+                        inner_val["counts"] = self.fake_one
 
                 # reset all other levels counts to 0
                 else:
-                    vv["counts"] = 0
+                    inner_val["counts"] = 0
 
             # propagate counts up from level 5 > 1
-            for idx, (kk, vv) in enumerate(sorted(v.items(), key=lambda x: x[1]["level"], reverse=True)):
-                if vv["parent"] != "":
-                    plot_tree[k][vv["parent"]]["counts"] += vv["counts"]
+            for inner_key, inner_val in sorted(val.items(), key=lambda x: x[1]["level"], reverse=True):
+                if inner_val["parent"] != "":
+                    plot_tree[key][inner_val["parent"]]["counts"] += inner_val["counts"]
 
                     # propagate counts (overwrite imported counts) if enabled
-                    match self.s["atc_propagate_counts"]:
-                        case "level":
-                            if vv["level"] > self.s["atc_propagate_lvl"]:
-                                plot_tree[k][vv["parent"]]["imported_counts"] += vv["imported_counts"]
-                        case "all":
-                            plot_tree[k][vv["parent"]]["imported_counts"] += vv["imported_counts"]
+                    propagate_mode = self.s["atc_propagate_counts"]
+                    if propagate_mode == "level":
+                        if inner_val["level"] > self.s["atc_propagate_lvl"]:
+                            plot_tree[key][inner_val["parent"]]["imported_counts"] += inner_val["imported_counts"]
+                    elif propagate_mode == "all":
+                        plot_tree[key][inner_val["parent"]]["imported_counts"] += inner_val["imported_counts"]
 
         # when counts are propagated, begin color propagation
-
         self.tree_color_propagation(plot_tree=plot_tree, count_key="imported_counts")
 
         # create figure
@@ -1567,6 +1561,7 @@ class DrugSunburst(SunburstBase):
 
 
 def show_help():
+    """prints help to console"""
     print(" DrugVision - Minimal Reproducible Examples ".center(120, "-"))
     print('''
 from ontoloviz.core import PhenotypeSunburst, DrugSunburst
@@ -1598,4 +1593,4 @@ d.plot
 
 
 if __name__ == "__main__":
-    show_help()    
+    show_help()
